@@ -22,7 +22,10 @@ cd ..
 #     cp -aR ${CURRENT} ${NEW}
 # fi
 
-cp --exclude=.git -aR ${CURRENT} ${NEW}
+cp -aR ${CURRENT} ${NEW}
+rm -rf ${NEW}/.git
+rm -rf ${NEW}/.github
+rm -rf ${NEW}/.pytest_cache
 
 rm backintime-$VER.tar.gz
 
@@ -52,5 +55,5 @@ echo ""
 echo "RESULT:"
 realpath backintime-$VER.tar.gz
 
-# rm -rf backintime-$VER
+rm -rf ${NEW}
 
