@@ -39,17 +39,19 @@ class EncfsCreateWarning(_EncfsWarningBase):
     """
 
     def __init__(self, parent):
-        text = _('Support for EncFS will be discontinued in the '
-                 'foreseeable future. It is not recommended to use that '
-                 'mode for a profile furthermore.')
+        text = _('EncFS profile creation will be removed in the next minor '
+                 'release (1.7), scheduled for 2026.')
+        text = text + ' ' + _('It is not recommended to use that '
+                              'mode for a profile furthermore.')
         whitepaper = f'<a href="{URL_ENCRYPT_TRANSITION}">' \
             + _('whitepaper') + '</a>'
-        informative_text = _(
-            'A decision on a replacement for continued support of encrypted '
-            'backups is still pending, depending on project resources and '
-            'contributor availability. More details are available in this '
-            '{whitepaper}.'
-        ).format(whitepaper=whitepaper)
+
+        informative_text = _('Support for EncFS is being discontinued due '
+                             'to security vulnerabilities.')
+        informative_text = informative_text + ' ' + _(
+            'For more details, including potential alternatives, please refer '
+            'to this {whitepaper}.').format(
+                whitepaper=whitepaper)
 
         super().__init__(parent, text, informative_text)
 
@@ -62,10 +64,12 @@ class EncfsExistsWarning(_EncfsWarningBase):
         # DevNote: Code looks ugly because we need to take the needs of
         # translators into account. Also the limitations of Qt's RichText
         # feature need to be considered.
-
-        text = _('The support for encrypted snapshot profiles is undergoing '
-                 'significant changes, and EncFS will be removed in the '
-                 'foreseeable future.')
+        text = ' '.join([
+            _('EncFS profile creation will be removed in the next minor '
+              'release (1.7), scheduled for 2026.'),
+            _('It is not recommended to use that mode for a '
+              'profile furthermore.')
+        ])
 
         profiles = '<ul>' \
             + ''.join(f'<li>{profile}</li>' for profile in profiles) \
@@ -73,14 +77,17 @@ class EncfsExistsWarning(_EncfsWarningBase):
 
         whitepaper = f'<a href="{URL_ENCRYPT_TRANSITION}">' \
             + _('whitepaper') + '</a>'
+
         info_paragraphs = (
             _('The following profile(s) use encryption with EncFS:'),
             profiles,
-            _('A decision on a replacement for continued support of encrypted '
-              'backups is still pending, depending on project resources and '
-              'contributor availability. Users are invited to join this '
-              'discussion. Updated details on the next steps are '
-              'available in this {whitepaper}.').format(
+            ' '.join([
+                _('Support for EncFS is being discontinued due '
+                  'to security vulnerabilities.'),
+                _('A replacement is planned, but it cannot be guaranteed that '
+                  'it will arrive on time.')]),
+            _('Users are invited to join this discussion. Updated details '
+              'on the next steps are available in this {whitepaper}.').format(
                   whitepaper=whitepaper),
             _('This message will not be shown again. This dialog is '
               'available at any time via the help menu.'),
