@@ -1,20 +1,13 @@
-# Back In Time
-# Copyright (C) 2008-2022 Oprea Dan, Bart de Koning, Richard Bailey,
-# Germar Reitze
+# SPDX-FileCopyrightText: © 2008-2022 Oprea Dan
+# SPDX-FileCopyrightText: © 2008-2022 Bart de Koning
+# SPDX-FileCopyrightText: © 2008-2022 Richard Bailey
+# SPDX-FileCopyrightText: © 2008-2022 Germar Reitze
 #
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
+# SPDX-License-Identifier: GPL-2.0-or-later
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License along
-# with this program; if not, write to the Free Software Foundation, Inc.,
-# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+# This file is part of the program "Back In Time" which is released under GNU
+# General Public License v2 (GPLv2). See LICENSES directory or go to
+# <https://spdx.org/licenses/GPL-2.0-or-later.html>.
 from PyQt6.QtGui import QFont
 from PyQt6.QtWidgets import (QDialog,
                              QLabel,
@@ -32,6 +25,7 @@ import encfstools
 import snapshotlog
 import tools
 import qttools
+from statedata import StateData
 
 
 class LogViewDialog(QDialog):
@@ -57,9 +51,8 @@ class LogViewDialog(QDialog):
         self.enableUpdate = False
         self.decode = None
 
-        w = self.config.intValue('qt.logview.width', 800)
-        h = self.config.intValue('qt.logview.height', 500)
-        self.resize(w, h)
+        state_data = StateData()
+        self.resize(*state_data.logview_dims)
 
         import icon
         self.setWindowIcon(icon.VIEW_SNAPSHOT_LOG)
@@ -109,13 +102,17 @@ class LogViewDialog(QDialog):
         # "Few" in Polish.
         # Research in translation community indicate this as the best fit to
         # the meaning of "all".
-        self.comboFilter.addItem(' + '.join((_('Errors'), _('Changes'))), snapshotlog.LogFilter.ERROR_AND_CHANGES)
+        self.comboFilter.addItem(
+            ' + '.join((_('Errors'), _('Changes'))),
+            snapshotlog.LogFilter.ERROR_AND_CHANGES)
         self.comboFilter.setCurrentIndex(self.comboFilter.count() - 1)
         self.comboFilter.addItem(_('Errors'), snapshotlog.LogFilter.ERROR)
         self.comboFilter.addItem(_('Changes'), snapshotlog.LogFilter.CHANGES)
         self.comboFilter.addItem(ngettext('Information', 'Information', 2),
                                  snapshotlog.LogFilter.INFORMATION)
-        self.comboFilter.addItem(_('rsync transfer failures (experimental)'), snapshotlog.LogFilter.RSYNC_TRANSFER_FAILURES)
+        self.comboFilter.addItem(
+            _('rsync transfer failures (experimental)'),
+            snapshotlog.LogFilter.RSYNC_TRANSFER_FAILURES)
 
         # text view
         self.txtLogView = QPlainTextEdit(self)
@@ -231,29 +228,37 @@ class LogViewDialog(QDialog):
 
         mode = self.comboFilter.itemData(self.comboFilter.currentIndex())
 
-        # TODO This expressions is hard to understand (watchPath is not a boolean!)
+        # TODO This expressions is hard to understand (watchPath is not a
+        # boolean!)
         if watchPath and self.sid is None:
-            # remove path from watch to prevent multiple updates at the same time
+            # remove path from watch to prevent multiple updates at the same
+            # time
             self.watcher.removePath(watchPath)
             # append only new lines to txtLogView
-            log = snapshotlog.SnapshotLog(self.config, self.comboProfiles.currentProfileID())
-            for line in log.get(mode = mode,
-                                decode = self.decode,
-                                skipLines = self.txtLogView.document().lineCount() - 1):
+            log = snapshotlog.SnapshotLog(
+                self.config, self.comboProfiles.currentProfileID())
+            for line in log.get(mode=mode,
+                                decode=self.decode,
+                                skipLines=self.txtLogView.document().lineCount()-1):
                 self.txtLogView.appendPlainText(line)
 
             # re-add path to watch after 5sec delay
-            alarm = tools.Alarm(callback = lambda: self.watcher.addPath(watchPath),
-                                overwrite = False)
+            alarm = tools.Alarm(
+                callback=lambda: self.watcher.addPath(watchPath),
+                overwrite=False)
             alarm.start(5)
 
         elif self.sid is None:
-            log = snapshotlog.SnapshotLog(self.config, self.comboProfiles.currentProfileID())
-            self.txtLogView.setPlainText('\n'.join(log.get(mode = mode, decode = self.decode)))
+            log = snapshotlog.SnapshotLog(
+                self.config, self.comboProfiles.currentProfileID())
+            self.txtLogView.setPlainText(
+                '\n'.join(log.get(mode=mode, decode=self.decode)))
+
         else:
-            self.txtLogView.setPlainText('\n'.join(self.sid.log(mode, decode = self.decode)))
+            self.txtLogView.setPlainText(
+                '\n'.join(self.sid.log(mode, decode=self.decode)))
 
     def closeEvent(self, event):
-        self.config.setIntValue('qt.logview.width', self.width())
-        self.config.setIntValue('qt.logview.height', self.height())
+        state_data = StateData()
+        state_data.logview_dims = (self.width(), self.height())
         event.accept()
